..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

.. automodule:: invenio_rest.ext
   :members:

Decorators
----------

.. automodule:: invenio_rest.decorators
   :members:

Errors
------

.. automodule:: invenio_rest.errors
   :members:

Views
-----

.. automodule:: invenio_rest.views
   :members:
